@@ -134,6 +134,7 @@ fr_application_activate_about (GSimpleAction *action,
 			       "translator-credits", _("translator-credits"),
 			       "logo-icon-name", "org.gnome.ArchiveManager",
 			       "license-type", GTK_LICENSE_GPL_2_0,
+			       "website", "https://wiki.gnome.org/Apps/FileRoller",
 			       "wrap-license", TRUE,
 			       NULL);
 }
@@ -163,7 +164,9 @@ static const FrAccelerator fr_app_accelerators[] = {
 	{ "app.new", "<Control>n" },
 	{ "app.open", "<Control>o" },
 	{ "app.help", "F1" },
-	{ "app.quit", "<Control>q" }
+	{ "app.quit", "<Control>q" },
+	{ "app.list-mode::flat", "<Control>1" },
+	{ "app.list-mode::as-dir", "<Control>2" },
 };
 
 
